# NanGram

Negative Nancy's expression generator & parser! XD

Write grammars, generate random expressions, parse expressions.

## Installation

```bash
pip install nangram
```

## Usage

_TODO:_

See `examples/english.bnf` and `examples/english.py` for an example.
